@@ -5,7 +5,7 @@ sub Mojo::Weixin::_is_need_login {
     $self->debug("检查登录Cookie是否有效...");
     my $data = $self->http_get($api,{ua_debug_res_body=>0});
     my $ret = $data=~/window\.MMCgi\s*=\s*{\s*isLogin\s*:\s*(!!"1")\s*}/s?0:1;
-    if($ret){
+    if(not $ret){
         $self->debug("登录cookie仍然有效，可以免扫码登录");
     }
     else{
